# API reference

## Feature Effect Methods

### ::: effector.global_effect_ale.ALEBase
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - eval
           - plot

### ::: effector.global_effect_ale.ALE
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - __init__
           - fit

### ::: effector.global_effect_ale.RHALE
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - __init__
           - fit

### ::: effector.global_effect_pdp.PDPBase
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
          - fit
          - eval
          - plot


### ::: effector.global_effect_pdp.PDP
      options:
        show_root_heading: True
        show_symbol_type_toc: True
        members:
          - __init__

### ::: effector.global_effect_pdp.DerivativePDP
      options:
        show_root_heading: True
        show_symbol_type_toc: True
        members:
          - __init__

### ::: effector.global_effect_shap.SHAPDependence
      options:
        show_root_heading: True
        show_symbol_type_toc: True
        members:
          - __init__
          - fit
          - eval
          - plot

## Regional Effect Methods

### ::: effector.regional_effect.RegionalEffectBase
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - eval
           - plot
           - print_tree
           - print_level_stats
           - get_node_info           
           - describe_regions


### ::: effector.regional_effect_ale.RegionalALE
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
            - __init__
            - fit


### ::: effector.regional_effect_ale.RegionalRHALE
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
            - __init__
            - fit

### ::: effector.regional_effect_pdp.RegionalPDPBase
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
            - fit

### ::: effector.regional_effect_pdp.RegionalPDP
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
            - __init__

### ::: effector.regional_effect_pdp.RegionalDerivativePDP
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
            - __init__

### ::: effector.regional_effect_shap.RegionalSHAP
       options:
            show_root_heading: True
            show_symbol_type_toc: True
            members:
                - __init__
                - fit


## Binning Methods
### ::: effector.binning_methods.Fixed
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - __init__

### ::: effector.binning_methods.Greedy
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - __init__

### ::: effector.binning_methods.DynamicProgramming
       options:
         show_root_heading: True
         show_symbol_type_toc: True
         members:
           - __init__


## Utils
### ::: effector.utils
      options:
        show_root_heading: False
